@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import Union, List
+from typing import List, Union
 
 from ._base import TiDBCloudyBase, TiDBCloudyField, TiDBCloudyListField
 from .util.ip import get_current_ip_address
@@ -24,6 +24,8 @@ class ClusterStatus(Enum):
     RESUMING = "RESUMING"
     UNAVAILABLE = "UNAVAILABLE"
     IMPORTING = "IMPORTING"
+    MAINTAINING = "MAINTAINING"
+    PAUSING = "PAUSING"
     CLEARED = "CLEARED"
 
 
@@ -120,8 +122,8 @@ class TiDBNodeMap(TiDBCloudyBase):
 
 
 class TiKVNodeMap(TiDBCloudyBase):
-    __slots__ = [
-        "_node_name", "_availability_zone", "_node_size", "_vcpu_num", "_ram_bytes", "_storage_size_gib", "_status"]
+    __slots__ = ["_node_name", "_availability_zone", "_node_size", "_vcpu_num", "_ram_bytes", "_storage_size_gib",
+                 "_status"]
 
     node_name: str = TiDBCloudyField(str)
     availability_zone: str = TiDBCloudyField(str)
@@ -274,23 +276,17 @@ class CreateClusterConfig:
                 "components": {
                     "tidb": {
                         "node_size": self._tidb.node_size,
-                        "node_quantity": self._tidb.node_quantity
-                    } if self._tidb is not None else None,
+                        "node_quantity": self._tidb.node_quantity} if self._tidb is not None else None,
                     "tikv": {
                         "node_size": self._tikv.node_size,
                         "node_quantity": self._tikv.node_quantity,
-                        "storage_size_gib": self._tikv.storage_size_gib
-                    } if self._tikv is not None else None,
+                        "storage_size_gib": self._tikv.storage_size_gib} if self._tikv is not None else None,
                     "tiflash": {
                         "node_size": self._tiflash.node_size,
                         "node_quantity": self._tiflash.node_quantity,
-                        "storage_size_gib": self._tiflash.storage_size_gib
-                    } if self._tiflash is not None else None
-                },
-                "ip_access_list": [
-                    item.to_object() for item in self._ip_access_list] if self._ip_access_list is not None else None
-            }
-        }
+                        "storage_size_gib": self._tiflash.storage_size_gib} if self._tiflash is not None else None},
+                "ip_access_list": [item.to_object() for item in
+                                   self._ip_access_list] if self._ip_access_list is not None else None}}
 
 
 class UpdateClusterConfig:
@@ -338,11 +334,7 @@ class UpdateClusterConfig:
             if self._tiflash.storage_size_gib is not None:
                 components["tiflash"]["storage_size_gib"] = self._tiflash.storage_size_gib
 
-        return {
-            "config": {
-                "components": components
-            }
-        }
+        return {"config": {"components": components}}
 
 
 class ClusterInfo(TiDBCloudyBase):
@@ -367,8 +359,88 @@ class ClusterInfoOfRestore(TiDBCloudyBase):
     status: ClusterStatus = TiDBCloudyField(ClusterStatus)
 
     def __repr__(self):
-        return "<id={}, name={}, status={}>".format(self.id, self.name,
-                                                    self.status.value if self.status is not None else None)
+        return "<id={}, name={}, status={}>".format(
+            self.id, self.name,
+            self.status.value if self.status is not None else None)
+
+
+class ProjectAWSCMEK(TiDBCloudyBase):
+    __slots__ = ["_region", "_kms_arn"]
+    region: str = None
+    kms_arn: str = None
+
+    def __repr__(self):
+        return "<region={}, kms_arn={}>".format(
+            self.region, self.kms_arn)
+
+
+class BillingBase(TiDBCloudyBase):
+    __slots__ = ["_credits", "_discounts", "_runningTotal", "_totalCost"]
+    credits: str = TiDBCloudyField(str)
+    discounts: str = TiDBCloudyField(str)
+    runningTotal: str = TiDBCloudyField(str)
+    totalCost: str = TiDBCloudyField(str)
+
+
+class BillingMonthOverview(BillingBase):
+    __slots__ = ["_billedMonth"] + BillingBase.__slots__
+    billedMonth: str = TiDBCloudyField(str)
+
+    def __repr__(self):
+        return "<BillingMonthOverview billed_month={} credits={} running_total={} total_cost={}>".format(
+            self.billedMonth, self.credits, self.runningTotal, self.totalCost)
+
+
+class BillingOtherCharges(BillingBase):
+    __slots__ = ["_chargeName"] + BillingBase.__slots__
+    chargeName: str = TiDBCloudyField(str)
+
+    def __repr__(self):
+        return "<BillingOtherCharges charge_name={} credits={} running_total={} total_cost={}>".format(
+            self.chargeName, self.credits, self.runningTotal, self.totalCost)
+
+
+class BillingProjectCharges(BillingBase):
+    __slots__ = ["_projectName"] + BillingBase.__slots__
+    projectName: str = TiDBCloudyField(str)
+
+    def __repr__(self):
+        return "<BillingProjectCharges project_name={} credits={} running_total={} total_cost={}>".format(
+            self.projectName, self.credits, self.runningTotal, self.totalCost)
+
+
+class BillingMonthSummaryByProject(TiDBCloudyBase):
+    __slots__ = ["_otherCharges", "_projects"]
+    otherCharges: list = TiDBCloudyListField(BillingOtherCharges)
+    projects: list = TiDBCloudyListField(BillingProjectCharges)
+
+    def __repr__(self):
+        return "<BillingMonthSummaryByProject other_charges={} projects={}>".format(
+            self.otherCharges, self.projects)
+
+
+class BillingServiceCost(TiDBCloudyBase):
+    __slots__ = []
+
+
+class BillingMonthSummaryByService(TiDBCloudyBase):
+    __slots__ = ["_serviceCosts", "_serviceName"]
+    serviceCosts: List[dict] = TiDBCloudyListField(BillingServiceCost)
+    serviceName: str = TiDBCloudyField(str)
+
+    def __repr__(self):
+        return "<BillingMonthSummaryByService service_name={} service_costs={}>".format(
+            self.serviceName, self.serviceCosts)
+
+
+class BillingMonthSummary(TiDBCloudyBase):
+    __slots__ = ["_overview", "_summaryByProject", "_summaryByService"]
+    overview: BillingMonthOverview = TiDBCloudyField(BillingMonthOverview)
+    summaryByProject: BillingMonthSummaryByProject = TiDBCloudyField(BillingMonthSummaryByProject)
+    summaryByService: BillingMonthSummaryByService = TiDBCloudyListField(BillingMonthSummaryByService)
+
+    def __repr__(self):
+        return "<BillingMonthSummary month={}>".format(self.overview.billedMonth)
 
 
 class CloudSpecification(TiDBCloudyBase):
@@ -383,5 +455,4 @@ class CloudSpecification(TiDBCloudyBase):
     def __repr__(self):
         return "<Specification cluster_type={} cloud_provider={} region={}>".format(
             self.cluster_type.value if self.cluster_type is not None else None,
-            self.cloud_provider.value if self.cloud_provider is not None else None,
-            self.region)
+            self.cloud_provider.value if self.cloud_provider is not None else None, self.region)
