@@ -1,4 +1,4 @@
-import requests
+import httpx
 import socket
 
 
@@ -7,7 +7,7 @@ def get_current_ip_address() -> str:
     addrs = socket.getaddrinfo(host, 80, family=socket.AF_INET, proto=socket.IPPROTO_TCP)
     for addr in addrs:
         ipv4_addr = addr[4][0]
-        resp = requests.get("http://" + ipv4_addr + "/ip", headers={"Host": host})
-        if resp.ok:
-            return resp.text.strip()
-    raise Exception("Failed to get current ip address")
+        resp = httpx.get("http://" + ipv4_addr + "/ip", headers={"Host": host})
+        resp.raise_for_status()
+        return resp.text.strip()
+    raise Exception("Failed to get the current IP address")
